@@ -11,10 +11,11 @@ use namespace::autoclean;
 
 # Use all the modules so we don't get weird dependency issues
 use Dist::Zilla::App::Command::xtest                  ();
-use Dist::Zilla::Plugin::ContributorsFile             ();
-use Dist::Zilla::Plugin::Git::Contributors            ();
 use Dist::Zilla::Plugin::CheckExtraTests              ();
+use Dist::Zilla::Plugin::ContributorsFile             ();
 use Dist::Zilla::Plugin::CopyFilesFromBuild::Filtered ();
+use Dist::Zilla::Plugin::Git::Contributors            ();
+use Dist::Zilla::Plugin::MetaProvides                 ();
 use Dist::Zilla::Plugin::MinimumPerl                  ();
 use Dist::Zilla::Plugin::PodWeaver                    ();
 use Dist::Zilla::Plugin::Prereqs::AuthorDeps          ();
@@ -27,7 +28,7 @@ use Dist::Zilla::Role::PluginBundle                   ();
 use Dist::Zilla::Role::PluginBundle::Easy             ();
 use Dist::Zilla::Util                                 ();
 
-our $VERSION = '1.9';
+our $VERSION = '2.0';
 
 with
     'Dist::Zilla::Role::PluginBundle::Easy',
@@ -179,10 +180,9 @@ sub _warn_me {
 }
 
 sub commit_files_after_release {
-    grep { -e } sort(uniq(
-            'README.pod',
-            'Changes',   shift->copy_files_from_release
-    ));
+    my $self = shift;
+    grep { -e }
+        sort(uniq('README.pod', 'Changes', $self->copy_files_from_release, $self->copy_files_from_build));
 }
 
 my %removed;
@@ -243,30 +243,56 @@ sub configure {
             },
         ],
 
+        [
+            'PromptIfStale' => 'stale modules, build' =>
+                { phase => 'build', module => [$self->meta->name] }
+        ],
+        [
+            'PromptIfStale' => 'stale modules, release' => {
+                phase             => 'release',
+                check_all_plugins => 1,
+                check_all_prereqs => 1
+            }
+        ],
+
         qw(PruneCruft ManifestSkip MetaYAML MetaJSON),
 
         ['License' => { filename => $self->license }],
 
-        qw(Readme ExecDir ShareDir MakeMaker Manifest
+        ['ReadmeFromPod' => { type => 'markdown', readme => 'README.md' }],
+
+        qw(ExecDir ShareDir MakeMaker Manifest
             TestRelease PodWeaver),
 
-        ['Git::Contributors'    => { order_by => 'commits' }],
-        ['ContributorsFile' => { filename => 'CONTRIBUTORS' }],
+        ['Git::Contributors' => { order_by => 'commits' }],
+        ['ContributorsFile'  => { filename => 'CONTRIBUTORS' }],
 
-        ['AutoPrereqs'         => { skip       => [qw(^perl$)] }],
+        ['AutoPrereqs'         => { skip       => [qw(^perl$ utf8 warnings strict)] }],
         ['Prereqs::AuthorDeps' => { ':version' => '0.006' }],
         [
-            'MinimumPerl' =>
-                { ':version' => '1.006',
-                    configure_finder => ':NoFiles'
-                }
+            'MinimumPerl' => {
+                ':version'       => '1.006',
+                configure_finder => ':NoFiles'
+            }
         ],
+        ['MetaProvides::Package'],
 
         ['CPANFile'],
 
-        [ 'CopyFilesFromBuild::Filtered' => {
-            copy => [ $self->copy_files_from_build ]
-        }],
+        [
+            'CopyFilesFromBuild::Filtered' =>
+                { copy => [$self->copy_files_from_build] }
+        ],
+
+        [ 'Git::Check' => 'initial check' => { allow_dirty => [ $self->airplane ? 'dist.ini' : '' ] } ],
+
+        qw(Git::CheckFor::MergeConflicts),
+        ['Git::Remote::Check' => { branch => 'master', remote_branch => 'master' } ],
+        ['Git::CheckFor::CorrectBranch' =>
+                { release_branch => 'master' }
+        ],
+
+        qw(CheckPrereqsIndexed),
 
         ['Repository'],
         ['ConfirmRelease'],
@@ -285,7 +311,8 @@ sub configure {
 
     if ($self->airplane) {
         _warn_me(
-            "Building in airplane mode, skipping network required modules");
+            "Building in airplane mode, skipping network required modules"
+        );
         @plugins = grep {
             my $plugin
                 = Dist::Zilla::Util->expand_config_package_name(
@@ -293,9 +320,6 @@ sub configure {
             not exists $network_plugins{$plugin}
         } @plugins;
 
-        # allow our uncommitted dist.ini edit which sets 'airplane = 1'
-        #push @{( first { ref eq 'ARRAY' && $_->[0] eq 'Git::Check' } @plugins )->[-1]{allow_dirty}}, 'dist.ini';
-
         # halt release after pre-release checks, but before ConfirmRelease
         push @plugins, 'BlockRelease';
     }
@@ -360,7 +384,7 @@ Dist::Zilla::PluginBundle::Author::WATERKIP - An plugin bundle for all distribut
 
 =head1 VERSION
 
-version 1.9
+version 2.0
 
 =head1 SYNOPSIS
 
@@ -368,6 +392,13 @@ In your F<dist.ini>:
 
     [@Author::WATERKIP]
 
+=head1 DESCRIPTION
+
+This is a L<Dist::Zilla> plugin bundle. It is somewhat equal to the
+following F<dist.ini>:
+
+    TODO: Show what is done
+
 =head1 METHODS
 
 =head2 configure
